@@ -3,6 +3,7 @@ from .inference.base import InferenceComponent
 from .inference.mlflow import MLFlowInferenceComponent
 from .loader.dataframe import DataFrameLoader
 from .resources.io_manager import io_manager
+from .s3_connection import S3Connection
 from .training.base import TrainingComponent
 from .training.doc2vec import Doc2VecTrainingComponent
 from .training.grid_search import GridSearchTrainingComponent
@@ -11,6 +12,7 @@ from .training.sklearn import SklearnComponent
 from .training.word2vec import Word2VecTrainingComponent
 from .transform.array import ArrayTransformer
 from .transform.base import TransformComponent
+from .transform.noun_phrase import NounPhraseComponent
 from .transform.tokenize import TokenizeComponent
 from .transform.train_test import TrainTestComponent
 from .transform.yake import YakeComponent
